# pywellbeing

This package is about computational models of human wellbeing. It currently
contains the Adaptive Motivation Model (AMM).


## AMM demo

This demo recreates many of the figures in the original paper by Rusk (2022).

```python

import pywellbeing as pywb
pop = pywb.examples.run_amm()

```

